import { Text, View } from '@tarojs/components'
import { useDidShow, usePullDownRefresh, useRouter } from '@tarojs/taro'
import { useMemo, useState } from 'react'
import classNames from 'classnames'
import Steps from '../components/steps'
import type { StepStatus } from '../components/steps/components/step'
import Step from '../components/steps/components/step'
import styles from './index.module.scss'
import IconFont from '@/components/iconfont/iconfont'
import LayoutBlock from '@/components/layoutBlock'
import { alert, goLink, handleTimeout } from '@/common/common'
import Divider from '@/components/Divider'
import Cell from '@/components/cell'
import { formatDateTime } from '@/common/format'
import { GetOrderEarlyWarningListApi } from '@/api/orderWarning'

interface NotificationProps{
  baseData?: any
}
const StatusHeader = (props: NotificationProps) => {
  const { baseData } = props

  const statusStyles = useMemo(() => {
    const res = {
      background: '',
      textColor: '',
      icon: null as React.ReactNode,
    }
    if (baseData.handle_status_name === '有异常') {
      res.background = styles.pendingBackground
      res.textColor = styles.pendingName
      res.icon = <IconFont name="icon-yujing" size={56} color="#a91832"></IconFont>
    }
    else if (baseData.handle_status_name === '已完成' || baseData.handle_status_name === '进行中') {
      res.background = styles.successBackground
      res.textColor = styles.passName
      res.icon = <IconFont name="icon-yujing" size={56} color="#337fff"></IconFont>
    }
    else if (baseData.handle_status_name === '超时完成') {
      res.background = styles.failBackground
      res.textColor = styles.failName
      res.icon = <IconFont name="icon-yujing" size={56} color="#e23855"></IconFont>
    }
    else {
      res.background = styles.cancelBackground
      res.textColor = styles.cancelName
      res.icon = <IconFont name="icon-yujing" size={56} color="#dedede"></IconFont>
    }
    return res
  }, [baseData])
  const totalTime = useMemo(() => {
    const totalMins = baseData?.order_process?.reduce((prev: number, cur: any) => {
      console.log('cur', cur)
      return prev + cur?.timeout_min
    }, 0)
    return handleTimeout(totalMins)
  }, [baseData])
  return <View className={classNames(styles.status, statusStyles.background)}>
    <View className={styles.statusLeft}>
      <View className={styles.statusTitle}>
        {statusStyles.icon}
        <Text className={classNames(styles.statusName, statusStyles.textColor)}>{baseData.handle_status_name}</Text>
      </View>
      <View className={styles.price}>
        {
          baseData.handle_status_name === '进行中'
            ? baseData.handle_status_name
            : null
        }
        {
          baseData.handle_status_name === '有异常'
            ? `${baseData.handle_status_name} 超时 ${totalTime}`
            : null
        }
        {
          baseData.handle_status_name === '超时完成'
            ? `总共超时 ${totalTime}`
            : null
        }
        {
          baseData.handle_status_name === '已取消'
            ? '订单已取消'
            : null
        }
      </View>
    </View>
  </View>
}

const statusLine = [
  {
    id: 1,
    order_warning_process: 1,
    colorClassName: 'wait',
    type: 'wait',
    typeName: '开始',
  },
  {
    id: 2,
    order_warning_process: 2,
    colorClassName: 'wait',
    type: 'wait',
    typeName: '接单',
  },
  {
    id: 3,
    order_warning_process: 3,
    colorClassName: 'wait',
    type: 'wait',
    typeName: '配布',
    children: [
      {
        id: 5,
        order_warning_process: 4,
        colorClassName: 'wait',
        type: 'wait',
        typeName: '提货',
      },
      {
        id: 6,
        order_warning_process: 5,
        colorClassName: 'wait',
        type: 'wait',
        typeName: '收款',
      },
    ],
  },
  {
    id: 7,
    order_warning_process: 6,
    colorClassName: 'wait',
    type: 'wait',
    typeName: '出仓',
  },
  {
    id: 8,
    order_warning_process: 7,
    colorClassName: 'wait',
    type: 'wait',
    typeName: '收货',
  },
]

const OrderWarningAnalysisDetail = () => {
  const router = useRouter()
  const { fetchData, state } = GetOrderEarlyWarningListApi()
  const [data, setData] = useState<any>({})
  const getData = async() => {
    const res = await fetchData({ sale_order_id: router?.params.id })
    if (res.success) {
      setData(res.data.list[0])
    }
    else {
      alert.error(res.msg)
    }
  }
  useDidShow(() => {
    if (router?.params.id) {
      getData()
    }
  })
  // 页面下拉刷新
  usePullDownRefresh(() => {
    getData()
  })

  const handleClickSaleOrderDetail = () => {
    goLink('/pages/orderDetails/index', { id: data?.sale_order_id })
  }

  const dispatchStatus = (item: any): { status: StepStatus } => {
    // 已处理 未超时  就是已完成
    if (item.is_handle && !item.is_timeout) {
      return {
        status: 'finish',
      }
    }
    else if (item.is_handle && item.is_timeout) { // 超时 已处理  就是超时完成
      return {
        status: 'error',
      }
    }
    else if (!item.is_handle && item.is_timeout) { // 超时 未处理  就是进行中异常
      return {
        status: 'process',
      }
    }
    else {
      return {
        status: 'wait',
      }
    }
  }

  return <View className={styles.main}>
    <View style={{ position: 'relative', paddingTop: '90px' }}>
      <StatusHeader baseData={data} />
    </View>
    <LayoutBlock customStyle={{ padding: '20rpx 32rpx' }} circle onClick={handleClickSaleOrderDetail}>
      <View className="flex-row items-center justify-between">
        <View style={{ fontSize: '28rpx', fontWeight: 500 }}>单号：{data?.sale_order_no}</View>
        <IconFont name="icon-chakanquanbukehu" size={38} color="#5f5f5f"></IconFont>
      </View>
      <Divider direction="horizontal" customStyles={{ margin: '20rpx 0 10rpx 0 ' }}></Divider>
      <Cell title="条数米数：" desc={data?.roll_or_length}></Cell>
      <Cell title="地址信息：" desc={data?.address}></Cell>
      <Cell title="业务员：" desc={data?.sale_user_name}></Cell>
    </LayoutBlock>
    <LayoutBlock customStyle={{ padding: '20rpx 32rpx' }} circle onClick={handleClickSaleOrderDetail}>
      <Steps customClassName={styles.step_outside} direction="vertical">
        {
          statusLine.map((item, key) => {
            let index = data?.order_process?.findIndex(i => i.order_warning_process === item.order_warning_process)
            index = index == null ? -1 : index
            if (index !== -1) {
              const target = data?.order_process[index]
              return <Step status={dispatchStatus(target).status} key={key} title={
                <View className={classNames(styles['step-title'])}>
                  <Text className={styles['step-status']}>{target.order_warning_process_name}</Text>
                  <Text>{formatDateTime(target.complete_time)}</Text>
                </View>
              } description={
                <>
                  {

                    target.timeout_min !== 0
                      ? <View className={styles.timeout}>
            超时 {handleTimeout(target.timeout_min)}
                      </View>
                      : null
                  }
                  {
                    (item.children && item.children.length > 0)
                      ? item.children.map((subItem, subIndex) => {
                        let index = data?.order_process?.findIndex(i => i.order_warning_process === subItem.order_warning_process)
                        index = index == null ? -1 : index
                        if (index !== -1) {
                          const target = data?.order_process[index]
                          return <Step status={dispatchStatus(target).status} key={subIndex} title={
                            <View className={classNames(styles['step-title'])}>
                              <Text className={styles['step-status']}>{target.order_warning_process_name}</Text>
                              <Text>{formatDateTime(target.complete_time)}</Text>
                            </View>
                          } description={
                            target.timeout_min !== 0
                              ? <View className={styles.timeout}>超时 {handleTimeout(target.timeout_min)}</View>
                              : null
                          }
                          ></Step>
                        }
                        else {
                          return <Step status="wait" key={subIndex} title={
                            <View className={classNames(styles['step-title'])}>
                              <Text className={styles['step-status']}>{subItem.typeName}</Text>
                              <Text>未开始</Text>
                            </View>
                          } description=""
                          ></Step>
                        }
                      })
                      : null

                  }
                </>

              }
              ></Step>
            }
            else {
              return <Step status="wait" key={key} title={
                <View className={classNames(styles['step-title'])}>
                  <Text className={styles['step-status']}>{item.typeName}</Text>
                  <Text>未开始</Text>
                </View>
              } description={
                (item.children && item.children.length > 0)
                  ? item.children.map((subItem, subIndex) => {
                    return <Step status="wait" key={subIndex} title={
                      <View className={classNames(styles['step-title'])}>
                        <Text className={styles['step-status']}>{subItem.typeName}</Text>
                        <Text>未开始</Text>
                      </View>
                    } description=""
                    ></Step>
                  })
                  : null
              }
              ></Step>
            }
          })
        }
      </Steps>
    </LayoutBlock>
  </View>
}
export default OrderWarningAnalysisDetail
